pub enum LifecyclePerformerResponse {
Receipt(Datum),
AcknowledgementMissing,
}Expand description
Result of calling a lifecycle performer after durable dispatch.
Variants
Receipt(Datum)
The performer returned an uninterpreted raw acknowledgement.
AcknowledgementMissing
Performance may have occurred, but its acknowledgement was lost.