pub struct OperationIntent { /* private fields */ }Expand description
Canonical semantic intent whose identity survives grants, attempts, and leases.
Implementations
Sourceimpl OperationIntent
impl OperationIntent
Sourcepub fn new(
operation: impl Into<String>,
target: Datum,
intended_result: Datum,
replay_policy: ReplayPolicy,
) -> Result<Self, OperationError>
pub fn new( operation: impl Into<String>, target: Datum, intended_result: Datum, replay_policy: ReplayPolicy, ) -> Result<Self, OperationError>
Constructs and identifies one immutable intent.
Sourcepub const fn id(&self) -> &OperationId
pub const fn id(&self) -> &OperationId
Returns the stable operation identity.
Sourcepub const fn intended_result(&self) -> &Datum
pub const fn intended_result(&self) -> &Datum
Returns the intended semantic postcondition.
Sourcepub const fn replay_policy(&self) -> ReplayPolicy
pub const fn replay_policy(&self) -> ReplayPolicy
Returns the replay rule bound into this intent.
Sourcepub fn canonical_datum(&self) -> Datum
pub fn canonical_datum(&self) -> Datum
Returns the exact canonical value whose id is Self::id.