pub struct OperationLifecycleRecord { /* private fields */ }Expand description
Complete verified lifecycle history reconstructed only from the journal.
Implementations
Sourceimpl OperationLifecycleRecord
impl OperationLifecycleRecord
Sourcepub const fn intent(&self) -> &OperationIntent
pub const fn intent(&self) -> &OperationIntent
Returns the immutable intent.
Sourcepub const fn grant(&self) -> &OperationGrant
pub const fn grant(&self) -> &OperationGrant
Returns the separately recorded grant.
Sourcepub fn leases(&self) -> &[OperationLease]
pub fn leases(&self) -> &[OperationLease]
Returns every bounded lease in durable order.
Sourcepub fn attempts(&self) -> &[OperationAttempt]
pub fn attempts(&self) -> &[OperationAttempt]
Returns every attempt in durable order.
Sourcepub fn dispatches(&self) -> &[FencedDispatch]
pub fn dispatches(&self) -> &[FencedDispatch]
Returns every dispatch in durable order.
Sourcepub fn receipts(&self) -> &[LifecycleReceipt]
pub fn receipts(&self) -> &[LifecycleReceipt]
Returns every raw receipt in durable order.
Sourcepub fn observations(&self) -> &[OperationObservation]
pub fn observations(&self) -> &[OperationObservation]
Returns every independent observation in durable order.
Sourcepub fn outcome(&self) -> Option<&OperationOutcome>
pub fn outcome(&self) -> Option<&OperationOutcome>
Returns the latest durable outcome.
Sourcepub fn outcome_id(&self) -> Option<&OperationOutcomeId>
pub fn outcome_id(&self) -> Option<&OperationOutcomeId>
Returns the semantic identity of the latest durable outcome.